@@ -11,11 +11,11 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
-our $VERSION = '1.100430';
+our $VERSION = '1.100660';
 # ABSTRACT: all git plugins in one go
 
 use Moose;
-use Moose::Autobox;
+use Class::MOP;
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -25,14 +25,17 @@ sub bundle_config {
     my $arg   = $section->{payload};
 
     # bundle all git plugins
-    my @classes =
-        map { "Dist::Zilla::Plugin::Git::$_" }
-        qw{ Check Commit Tag Push };
+    my @names   = qw{ Check Commit Tag Push };
 
-    # make sure all plugins exist
-    eval "require $_; 1" or die for @classes; ## no critic ProhibitStringyEval
+    my @config;
 
-    return @classes->map(sub { [ "$class/$_" => $_ => $arg ] })->flatten;
+    for my $name (@names) {
+        my $class = "Dist::Zilla::Plugin::Git::$name";
+        Class::MOP::load_class($class);
+        push @config, [ "$section->{name}/$name" => $class => $arg ];
+    }
+
+    return @config;
 }
 
 
@@ -49,7 +52,7 @@ Dist::Zilla::PluginBundle::Git - all git plugins in one go
 
 =head1 VERSION
 
-version 1.100430
+version 1.100660
 
 =head1 SYNOPSIS
 
